<?php

namespace Odhen\API\Service;

use \SimpleXMLElement;

class WiBX {

    protected $entityManager;
    protected $instanceManager;
    protected $sessionHandler;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager, \Zeedhi\Framework\DependencyInjection\InstanceManager $instanceManager, \Helpers\Environment $sessionHandler){
        $this->entityManager = $entityManager;
        $this->instanceManager = $instanceManager;
        $this->sessionHandler = $sessionHandler;
    }

    const CALL_HEALTHCHECK = 'healthcheck';
    const CALL_QUOTATIONS = 'quotations';
    const CALL_PAYMENTS = 'payments';
    const CALL_REPORTS = 'reports';

    public function healthcheck(){
        $this->callWiBX(self::CALL_HEALTHCHECK, json_encode(array()));
    }

    public function quotations($value, $saleCode){
        $params = array(
            'monetaryAmount' => $value,
            'referenceIdentifier' => $saleCode
        );

        return $this->callWiBX(self::CALL_QUOTATIONS, json_encode($params));
    }

    public function payments($value, $saleCode){
        $params = array(
            'referenceIdentifier' => $saleCode,
            'wibxAmount' => $value,
            'machineIdentifier' => '1'
        );

        return $this->callWiBX(self::CALL_PAYMENTS, json_encode($params));
    }

    private function callWiBX($method, $params){
        $URL = 'https://api.wiboo.io/qa-epp/v1/' . $method;

        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $URL);

        $apiKey = $this->sessionHandler->getUserInfo()['IDWIBXSELLER'];
        $wibxToken = $this->sessionHandler->getUserInfo()['IDWIBXTOKEN'];
        $enterpriseId = $this->sessionHandler->getUserInfo()['IDWIBXENTERP'];

        $headers = array(
            'Content-Type: application/json',
            'x-api-key : ' . $apiKey
        );
        if ($method == self::CALL_QUOTATIONS || $method == self::CALL_PAYMENTS){
            array_push($headers, 'x-wibx-token : ' . $wibxToken);
            array_push($headers, 'x-enterprise-id : ' . $enterpriseId);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $params);
        }

        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);

        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_TIMEOUT, 20);
        curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, 10);

        if (!empty($this->instanceManager->getParameter('PROXY_IP'))){
            curl_setopt($curl, CURLOPT_PROXY, $this->instanceManager->getParameter('PROXY_IP').":".$this->instanceManager->getParameter('PROXY_PORT'));
            if (!empty($this->instanceManager->getParameter('PROXY_USER'))){
                curl_setopt($curl, CURLOPT_PROXYUSERPWD, $this->instanceManager->getParameter('PROXY_USER').":".$this->instanceManager->getParameter('PROXY_PASSWORD'));
            }
        }

        $curl_response = curl_exec($curl);
        $err    = curl_errno($curl);
        $errmsg = curl_error($curl);
        curl_close($curl);
        // var_dump($curl_response);
        // var_dump($err);
        // var_dump($errmsg);die;

        if ($err){
            if ($err === 28){
                throw new \Exception("<br>N&atilde;o foi poss&iacute;vel estabelecer uma conex&atilde;o com o servidor da WiBX.");
            }
            else {
                throw new \Exception("<br>Ocorreu um erro na chamada WiBX:<br><br>" . $errmsg);
            }
        }

        if (empty($curl_response)){
            throw new \Exception("<br>N&atilde;o houve retorno do servidor WiBX.");
        }
        else {
            $result = json_decode($curl_response, true);

            if (empty($result)) throw new \Exception($curl_response);
            else if (array_key_exists('eventError', $result)){
                throw new \Exception("<br>Erro na requisição WiBX: <br><br>" . $result['stacktrace']);
            }
            else if (array_key_exists('message', $result)){
                throw new \Exception("<br>Erro na requisição WiBX: <br><br>" . $result['message']);
            }

            return $result;
        }
    }

}